@@ -113,6 +113,7 @@ def push_model(_: Info, path: str, url: str, org: str, token: str, slug: str, ve
     print("Pushing model to ", ref)
     model_meta['ref'] = ref
     remote_model_store = RemoteModelStore.parse_obj(model_meta)
+
     KodexaPlatform.deploy(ref, remote_model_store, name=model_meta['name'], description=model_meta['description'],
                           force_replace=True)
 
@@ -127,8 +128,8 @@ def push_model(_: Info, path: str, url: str, org: str, token: str, slug: str, ve
                 with open(path_hit, 'rb') as path_content:
                     remote_model_store.put(path_hit, path_content, replace=True)
 
-    remote_model_store.set_content_metadata(ModelContentMetadata.parse_obj(model_meta['metadata']))
-
+    model_metadata = ModelContentMetadata.parse_obj(model_meta['metadata'])
+    remote_model_store.set_content_metadata(model_metadata)
     print("Pushed model :tada:")
 
 
@@ -157,6 +158,37 @@ def deploy(_: Info, path: str, url: str, org: str, token: str):
 
     print("Deployed extension pack :tada:")
 
+@cli.command()
+@click.argument('id', required=True)
+@click.option('--url', default=KodexaPlatform.get_url(), help='The URL to the Kodexa server')
+@click.option('--token', default=KodexaPlatform.get_access_token(), help='Access token')
+@pass_info
+def project(_: Info, id: str, token: str, url: str):
+    """Get all the details for a specific project
+    """
+
+    KodexaPlatform.set_url(url)
+    KodexaPlatform.set_access_token(token)
+
+    KodexaPlatform.get_project(id)
+
+@cli.command()
+@click.argument('ref', required=True)
+@click.argument('path', required=True)
+@click.option('--url', default=KodexaPlatform.get_url(), help='The URL to the Kodexa server')
+@click.option('--token', default=KodexaPlatform.get_access_token(), help='Access token')
+@pass_info
+def upload(_: Info, ref: str, path: str, token: str, url: str):
+    """Upload the contents of a file or directory to a Kodexa platform instance
+    """
+
+    KodexaPlatform.set_url(url)
+    KodexaPlatform.set_access_token(token)
+
+    print(f"Uploading {path}")
+    KodexaPlatform.upload_file(ref, path)
+    print("Upload complete :tada:")
+
 
 @cli.command()
 @click.argument('object_type', required=True)
@@ -175,7 +207,7 @@ def apply(_: Info, object_type: str, ref: Optional[str], file: str, token: str,
     if file is None:
         print("Reading from stdin")
         if format == 'yaml':
-            obj = yaml.parse(sys.stdin.read())
+            obj = yaml.safe_load(sys.stdin.read())
         elif format == 'json':
             obj = json.loads(sys.stdin.read())
         else:
@@ -186,7 +218,7 @@ def apply(_: Info, object_type: str, ref: Optional[str], file: str, token: str,
             if file.lower().endswith('.json'):
                 obj = json.load(f)
             elif file.lower().endswith('.yaml'):
-                obj = yaml.parse(f)
+                obj = yaml.safe_load(f)
             else:
                 raise Exception("Unsupported file type")
 
@@ -241,11 +273,53 @@ def get(_: Info, object_type: str, ref: Optional[str], url: str, token: str, que
 @click.option('--sort', default=None, help='Sort by ie. name:asc')
 @pass_info
 def query(_: Info, query: str, ref: str, url: str, token: str, download: bool, page: int, pagesize: int, sort: None):
+    """
+    Query the documents in a given document store
+    """
     KodexaPlatform.set_url(url)
     KodexaPlatform.set_access_token(token)
     KodexaPlatform.query(ref, query, download, page, pagesize, sort)
 
 
+@cli.command()
+@click.argument('project_id', required=True)
+@click.argument('assistant_id', required=True)
+@click.option('--url', default=KodexaPlatform.get_url(), help='The URL to the Kodexa server')
+@click.option('--token', default=KodexaPlatform.get_access_token(), help='Access token')
+@click.option('--file', help='The path to the file containing the event to send')
+@click.option('--format', default=None, help='The format to use if from stdin (json, yaml)')
+@pass_info
+def send_event(_: Info, project_id: str, assistant_id: str, url: str, file: str, format: str, token: str):
+    """Send an event to an assistant
+    """
+
+    KodexaPlatform.set_access_token(token)
+    KodexaPlatform.set_url(url)
+
+    obj = None
+    if file is None:
+        print("Reading from stdin")
+        if format == 'yaml':
+            obj = yaml.parse(sys.stdin.read())
+        elif format == 'json':
+            obj = json.loads(sys.stdin.read())
+        else:
+            raise Exception("You must provide a format if using stdin")
+    else:
+        print("Reading event from file", file)
+        with open(file, 'r') as f:
+            if file.lower().endswith('.json'):
+                obj = json.load(f)
+            elif file.lower().endswith('.yaml'):
+                obj = yaml.full_load(f)
+            else:
+                raise Exception("Unsupported file type")
+
+    print("Sending event")
+    KodexaPlatform.send_event(project_id, assistant_id, obj)
+    print("Event sent :tada:")
+
+
 @cli.command()
 @click.argument('object_type', required=True)
 @click.argument('ref', required=True)
@@ -253,6 +327,9 @@ def query(_: Info, query: str, ref: str, url: str, token: str, download: bool, p
 @click.option('--token', default=KodexaPlatform.get_access_token(), help='Access token')
 @pass_info
 def reindex(_: Info, object_type: str, ref: str, url: str, token: str):
+    """
+    Reindex the given resource (based on ref)
+    """
     KodexaPlatform.set_url(url)
     KodexaPlatform.set_access_token(token)
     KodexaPlatform.reindex(object_type, ref)
@@ -262,6 +339,9 @@ def reindex(_: Info, object_type: str, ref: str, url: str, token: str):
 @pass_info
 @click.option('--python/--no-python', default=False, help='Print out the header for a Python file')
 def platform(_: Info, python: bool):
+    """
+    Get the details for the Kodexa instance we are logged into
+    """
     platform_url = KodexaPlatform.get_url()
 
     if platform_url is not None:
@@ -286,6 +366,9 @@ def platform(_: Info, python: bool):
 @click.option('--token', default=KodexaPlatform.get_access_token(), help='Access token')
 @pass_info
 def delete(_: Info, object_type: str, ref: str, url: str, token: str):
+    """
+    Delete the given resource (based on ref)
+    """
     KodexaPlatform.set_url(url)
     KodexaPlatform.set_access_token(token)
     KodexaPlatform.delete(object_type, ref)
@@ -348,6 +431,9 @@ def document(_: Info, path: str):
 @click.option('--url', default='http://www.example.com/', help='The base URL for the site links')
 @pass_info
 def package(_: Info, path: str, output: str, version: str, site: bool, sitedir: str, url: str):
+    """
+    Package an extension pack based on the kodexa.yml file
+    """
     metadata_obj = ExtensionHelper.load_metadata(path)
     print("Preparing to pack")
     try:
