@@ -1178,7 +1178,6 @@ class ContentNode(object):
           tag_name (str): tag name
           include_children (bool): include the children of this node
           value_separator (str): the string to be used to join related tag values
-          tag_uuid (optional(str)): limit to the given tag uuid
 
         Returns:
           a list of the tag values
@@ -2429,7 +2428,6 @@ class DocumentStore(Store):
             The last document to be stored in the family or None if there isn't one available
 
         """
-        document_family.content_objects.sort(key=lambda x: x.created_on, reverse=False)
         last_co = document_family.content_objects[-1]
         document = self.get_document_by_content_object(document_family, last_co)
 
@@ -2486,7 +2484,7 @@ class ModelStore(Store):
     def list_contents(self) -> List[str]:
         """
         Returns a list of the objects that have been uploaded into this model store
-        
+
         :return: a list of the object names
         """
         pass
