@@ -14,7 +14,6 @@ import sys
 import time
 from json import JSONDecodeError
 from pprint import pprint
-from typing import Optional
 
 import better_exceptions
 import jsonpickle
@@ -22,7 +21,6 @@ import requests
 import yaml
 from addict import Dict
 from appdirs import AppDirs
-from requests import Response
 from rich import print, get_console
 
 from kodexa.connectors import get_source
@@ -271,39 +269,6 @@ def resolve_object_type(obj_type):
         sys.exit(1)
 
 
-class KodexaClient:
-    """
-    A helper client that makes it a bit easier to work with the API on the platform
-
-    We wanted to use the OpenAPI V3 generator but it isn't yet able to cope with the structure
-    """
-
-    def __init__(self, url=None, access_token=None):
-        self.url = url
-        self.access_token = access_token
-
-    def get(self, api_path: str, params: Optional[dict] = None) -> Optional[Response]:
-        if params is None:
-            params = {}
-
-        url = f"{self.url}/{api_path}"
-        logger.info(f"Accessing {url}")
-
-        get_response = requests.get(
-            url,
-            params=params,
-            headers={"x-access-token": self.access_token})
-
-        if get_response.status_code == 200:
-            return get_response
-        elif get_response.status_code == 404:
-            return None
-        else:
-            msg = "Get failed [" + get_response.text + "], response " + str(get_response.status_code)
-            logger.warning(msg)
-            raise Exception(msg)
-
-
 class KodexaPlatform:
     """
     The KodexaPlatform object allows you to work with an instance of the Kodexa platform, allow you to list, view and deploy
@@ -316,10 +281,6 @@ class KodexaPlatform:
 
     """
 
-    @staticmethod
-    def get_client() -> KodexaClient:
-        return KodexaClient(KodexaPlatform.get_url(), KodexaPlatform.get_access_token())
-
     @staticmethod
     def get_access_token() -> str:
         """
@@ -1433,7 +1394,7 @@ class EventHelper:
 
     def log(self, message: str):
         requests.post(
-            f"{KodexaPlatform.get_url()}/api/sessions/{self.event.session_id}/executions/{self.event.execution_id}/logs",
+            f"{KodexaPlatform.get_url()}/api/sessions/{self.event.session_id}/executions/{self.event.execution.id}/logs",
             json=[
                 {'entry': message}
             ],
@@ -1441,14 +1402,14 @@ class EventHelper:
 
     def get_content_object(self, content_object_id: str):
         logger.info(
-            f"Getting content object {content_object_id} in event {self.event.id} in execution {self.event.execution_id}")
+            f"Getting content object {content_object_id} in event {self.event.id} in execution {self.event.execution.id}")
 
         co_response = requests.get(
-            f"{KodexaPlatform.get_url()}/api/sessions/{self.event.session_id}/executions/{self.event.execution_id}/objects/{content_object_id}",
+            f"{KodexaPlatform.get_url()}/api/sessions/{self.event.session_id}/executions/{self.event.execution.id}/objects/{content_object_id}",
             headers={'x-access-token': KodexaPlatform.get_access_token()}, timeout=300)
         if co_response.status_code != 200:
             logger.error(f"Response {co_response.status_code} {co_response.text}")
-            raise Exception(f"Unable to find content object {content_object_id} in execution {self.event.execution_id}")
+            raise Exception(f"Unable to find content object {content_object_id} in execution {self.event.execution.id}")
         return io.BytesIO(co_response.content)
 
     def put_content_object(self, content_object: ContentObject, content) -> ContentObject:
@@ -1460,7 +1421,7 @@ class EventHelper:
         }
         logger.info("Posting back content object to execution object")
         co_response = requests.post(
-            f"{KodexaPlatform.get_url()}/api/sessions/{self.event.session_id}/executions/{self.event.execution_id}/objects",
+            f"{KodexaPlatform.get_url()}/api/sessions/{self.event.session_id}/executions/{self.event.execution.id}/objects",
             data=data,
             headers={'x-access-token': KodexaPlatform.get_access_token()},
             files=files, timeout=300)
@@ -1476,7 +1437,7 @@ class EventHelper:
 
     def build_pipeline_context(self) -> PipelineContext:
         context = PipelineContext(context={}, content_provider=self,
-                                  store_provider=self, execution_id=self.event.execution_id)
+                                  store_provider=self, execution_id=self.event.execution.id)
 
         if self.event.store_ref and self.event.document_family_id:
             logger.info("We have storeRef and document family")
